( cd usr/lib64 ; rm -rf libX11-xcb.so.1 )
( cd usr/lib64 ; ln -sf libX11-xcb.so.1.0.0 libX11-xcb.so.1 )
( cd usr/lib64 ; rm -rf libX11-xcb.so )
( cd usr/lib64 ; ln -sf libX11-xcb.so.1.0.0 libX11-xcb.so )
( cd usr/lib64 ; rm -rf libX11.so.6 )
( cd usr/lib64 ; ln -sf libX11.so.6.2.0 libX11.so.6 )
( cd usr/lib64 ; rm -rf libX11.so )
( cd usr/lib64 ; ln -sf libX11.so.6.2.0 libX11.so )
